summaryrefslogtreecommitdiffstats
path: root/kresources/scalix
diff options
context:
space:
mode:
Diffstat (limited to 'kresources/scalix')
-rw-r--r--kresources/scalix/kabc/resourcescalix.cpp42
-rw-r--r--kresources/scalix/kabc/resourcescalix.h6
-rw-r--r--kresources/scalix/kcal/resourcescalix.cpp82
-rw-r--r--kresources/scalix/kcal/resourcescalix.h22
-rw-r--r--kresources/scalix/kioslave/scalix.cpp12
-rw-r--r--kresources/scalix/knotes/resourcescalix.cpp30
-rw-r--r--kresources/scalix/knotes/resourcescalix.h8
-rw-r--r--kresources/scalix/scalixadmin/delegatedialog.cpp10
-rw-r--r--kresources/scalix/scalixadmin/delegatepage.cpp10
-rw-r--r--kresources/scalix/scalixadmin/otherusermanager.cpp2
-rw-r--r--kresources/scalix/scalixadmin/otheruserpage.cpp14
-rw-r--r--kresources/scalix/scalixadmin/outofofficepage.cpp10
-rw-r--r--kresources/scalix/scalixadmin/passwordpage.cpp18
-rw-r--r--kresources/scalix/shared/kmailconnection.cpp20
-rw-r--r--kresources/scalix/shared/kmailconnection.h12
-rw-r--r--kresources/scalix/shared/resourcescalixbase.cpp8
-rw-r--r--kresources/scalix/shared/resourcescalixbase.h12
-rw-r--r--kresources/scalix/shared/scalixbase.cpp8
-rw-r--r--kresources/scalix/shared/subresource.cpp6
-rw-r--r--kresources/scalix/shared/subresource.h8
20 files changed, 170 insertions, 170 deletions
diff --git a/kresources/scalix/kabc/resourcescalix.cpp b/kresources/scalix/kabc/resourcescalix.cpp
index 31ccdf2c..55b2ed2e 100644
--- a/kresources/scalix/kabc/resourcescalix.cpp
+++ b/kresources/scalix/kabc/resourcescalix.cpp
@@ -155,7 +155,7 @@ void KABC::ResourceScalix::releaseSaveTicket( Ticket* ticket )
TQString KABC::ResourceScalix::loadContact( const TQString& contactData,
const TQString& subResource,
- Q_UINT32 sernum,
+ TQ_UINT32 sernum,
KMailICalIface::StorageFormat )
{
KABC::Addressee addr = Contact::fromXml( contactData );
@@ -204,7 +204,7 @@ bool KABC::ResourceScalix::loadSubResourceHelper( const TQString& subResource,
}
for ( int startIndex = 0; startIndex < count; startIndex += nbMessages ) {
- TQMap<Q_UINT32, TQString> lst;
+ TQMap<TQ_UINT32, TQString> lst;
if ( !kmailIncidences( lst, mimetype, subResource, startIndex, nbMessages ) ) {
kdError() << "Communication problem in ResourceScalix::load()\n";
@@ -213,7 +213,7 @@ bool KABC::ResourceScalix::loadSubResourceHelper( const TQString& subResource,
return false;
}
- for( TQMap<Q_UINT32, TQString>::ConstIterator it = lst.begin(); it != lst.end(); ++it ) {
+ for( TQMap<TQ_UINT32, TQString>::ConstIterator it = lst.begin(); it != lst.end(); ++it ) {
loadContact( it.data(), subResource, it.key(), format );
}
if ( progressId ) {
@@ -316,7 +316,7 @@ bool KABC::ResourceScalix::kmailUpdateAddressee( const Addressee& addr )
{
const TQString uid = addr.uid();
TQString subResource;
- Q_UINT32 sernum;
+ TQ_UINT32 sernum;
if ( mUidMap.find( uid ) != mUidMap.end() ) {
subResource = mUidMap[ uid ].resource();
if ( !subresourceWritable( subResource ) ) {
@@ -377,7 +377,7 @@ void KABC::ResourceScalix::insertAddressee( const Addressee& addr )
const TQString uid = addr.uid();
//kdDebug(5650) << k_funcinfo << uid << endl;
bool ok = false;
- if ( mUidMap.contains( uid ) ) {
+ if ( mUidMap.tqcontains( uid ) ) {
mUidsPendingUpdate.append( uid );
} else {
mUidsPendingAdding.append( uid );
@@ -414,7 +414,7 @@ void KABC::ResourceScalix::removeAddressee( const Addressee& addr )
*/
bool KABC::ResourceScalix::fromKMailAddIncidence( const TQString& type,
const TQString& subResource,
- Q_UINT32 sernum,
+ TQ_UINT32 sernum,
int format,
const TQString& contactXML )
{
@@ -429,8 +429,8 @@ bool KABC::ResourceScalix::fromKMailAddIncidence( const TQString& type,
//kdDebug(5650) << k_funcinfo << uid << endl;
// Emit "addressbook changed" if this comes from kmail and not from the GUI
- if ( !mUidsPendingAdding.contains( uid )
- && !mUidsPendingUpdate.contains( uid ) ) {
+ if ( !mUidsPendingAdding.tqcontains( uid )
+ && !mUidsPendingUpdate.tqcontains( uid ) ) {
addressBook()->emitAddressBookChanged();
} else {
mUidsPendingAdding.remove( uid );
@@ -451,11 +451,11 @@ void KABC::ResourceScalix::fromKMailDelIncidence( const TQString& type,
//kdDebug(5650) << k_funcinfo << uid << endl;
// Can't be in both, by contract
- if ( mUidsPendingDeletion.contains( uid ) ) {
+ if ( mUidsPendingDeletion.tqcontains( uid ) ) {
mUidsPendingDeletion.remove( uid );
- } else if ( mUidsPendingUpdate.contains( uid ) ) {
+ } else if ( mUidsPendingUpdate.tqcontains( uid ) ) {
// It's good to know if was deleted, but we are waiting on a new one to
- // replace it, so let's just sit tight.
+ // tqreplace it, so let's just sit tight.
} else {
// We didn't trigger this, so KMail did, remove the reference to the uid
mAddrMap.remove( uid );
@@ -483,7 +483,7 @@ void KABC::ResourceScalix::fromKMailAddSubresource( const TQString& type,
{
if( type != s_kmailContentsType ) return;
- if ( mSubResources.contains( subResource ) )
+ if ( mSubResources.tqcontains( subResource ) )
// Already registered
return;
@@ -500,7 +500,7 @@ void KABC::ResourceScalix::fromKMailDelSubresource( const TQString& type,
{
if( type != s_kmailContentsType ) return;
- if ( !mSubResources.contains( subResource ) )
+ if ( !mSubResources.tqcontains( subResource ) )
// Not registered
return;
@@ -535,13 +535,13 @@ void KABC::ResourceScalix::fromKMailDelSubresource( const TQString& type,
-void KABC::ResourceScalix::fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>& map,
+void KABC::ResourceScalix::fromKMailAsyncLoadResult( const TQMap<TQ_UINT32, TQString>& map,
const TQString& /* type */,
const TQString& folder )
{
// FIXME
KMailICalIface::StorageFormat format = KMailICalIface::StorageXML;
- for( TQMap<Q_UINT32, TQString>::ConstIterator it = map.begin(); it != map.end(); ++it ) {
+ for( TQMap<TQ_UINT32, TQString>::ConstIterator it = map.begin(); it != map.end(); ++it ) {
loadContact( it.data(), folder, it.key(), format );
}
if ( !addressBook() ){
@@ -557,7 +557,7 @@ TQStringList KABC::ResourceScalix::subresources() const
bool KABC::ResourceScalix::subresourceActive( const TQString& subresource ) const
{
- if ( mSubResources.contains( subresource ) ) {
+ if ( mSubResources.tqcontains( subresource ) ) {
return mSubResources[ subresource ].active();
}
@@ -569,7 +569,7 @@ bool KABC::ResourceScalix::subresourceActive( const TQString& subresource ) cons
bool KABC::ResourceScalix::subresourceWritable( const TQString& subresource ) const
{
- if ( mSubResources.contains( subresource ) ) {
+ if ( mSubResources.tqcontains( subresource ) ) {
return mSubResources[ subresource ].writable();
}
return false; //better a safe default
@@ -577,7 +577,7 @@ bool KABC::ResourceScalix::subresourceWritable( const TQString& subresource ) co
int KABC::ResourceScalix::subresourceCompletionWeight( const TQString& subresource ) const
{
- if ( mSubResources.contains( subresource ) ) {
+ if ( mSubResources.tqcontains( subresource ) ) {
return mSubResources[ subresource ].completionWeight();
}
@@ -588,7 +588,7 @@ int KABC::ResourceScalix::subresourceCompletionWeight( const TQString& subresour
TQString KABC::ResourceScalix::subresourceLabel( const TQString& subresource ) const
{
- if ( mSubResources.contains( subresource ) ) {
+ if ( mSubResources.tqcontains( subresource ) ) {
return mSubResources[ subresource ].label();
}
@@ -598,7 +598,7 @@ TQString KABC::ResourceScalix::subresourceLabel( const TQString& subresource ) c
void KABC::ResourceScalix::setSubresourceCompletionWeight( const TQString& subresource, int completionWeight )
{
- if ( mSubResources.contains( subresource ) ) {
+ if ( mSubResources.tqcontains( subresource ) ) {
mSubResources[ subresource ].setCompletionWeight( completionWeight );
} else {
kdDebug(5650) << "setSubresourceCompletionWeight: subresource " << subresource << " not found" << endl;
@@ -617,7 +617,7 @@ TQMap<TQString, TQString> KABC::ResourceScalix::uidToResourceMap() const
void KABC::ResourceScalix::setSubresourceActive( const TQString &subresource, bool active )
{
- if ( mSubResources.contains( subresource ) ) {
+ if ( mSubResources.tqcontains( subresource ) ) {
mSubResources[ subresource ].setActive( active );
load();
} else {
diff --git a/kresources/scalix/kabc/resourcescalix.h b/kresources/scalix/kabc/resourcescalix.h
index 25eca7e4..70eb7c92 100644
--- a/kresources/scalix/kabc/resourcescalix.h
+++ b/kresources/scalix/kabc/resourcescalix.h
@@ -112,12 +112,12 @@ public:
void fromKMailDelSubresource( const TQString& type, const TQString& id );
bool fromKMailAddIncidence( const TQString& type, const TQString& resource,
- Q_UINT32 sernum, int format, const TQString& contact );
+ TQ_UINT32 sernum, int format, const TQString& contact );
void fromKMailDelIncidence( const TQString& type, const TQString& resource,
const TQString& contact );
void fromKMailRefresh( const TQString& type, const TQString& resource );
- void fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>& map,
+ void fromKMailAsyncLoadResult( const TQMap<TQ_UINT32, TQString>& map,
const TQString& type,
const TQString& folder );
@@ -153,7 +153,7 @@ protected:
bool loadSubResource( const TQString& subResource );
bool loadSubResourceHelper( const TQString& subResource, const char* mimetype, KMailICalIface::StorageFormat format );
TQString loadContact( const TQString& contactData, const TQString& subResource,
- Q_UINT32 sernum, const KMailICalIface::StorageFormat format );
+ TQ_UINT32 sernum, const KMailICalIface::StorageFormat format );
TQString configFile() const {
return Scalix::ResourceScalixBase::configFile( "kabc" );
diff --git a/kresources/scalix/kcal/resourcescalix.h b/kresources/scalix/kcal/resourcescalix.h
index 11baa5ec..e00909c7 100644
--- a/kresources/scalix/kcal/resourcescalix.h
+++ b/kresources/scalix/kcal/resourcescalix.h
@@ -105,7 +105,7 @@ public:
/// The ResourceScalixBase methods called by KMail
bool fromKMailAddIncidence( const TQString& type, const TQString& subResource,
- Q_UINT32 sernum, int format, const TQString& data );
+ TQ_UINT32 sernum, int format, const TQString& data );
void fromKMailDelIncidence( const TQString& type, const TQString& subResource,
const TQString& uid );
void fromKMailRefresh( const TQString& type, const TQString& subResource );
@@ -115,7 +115,7 @@ public:
const TQString& label, bool writable );
void fromKMailDelSubresource( const TQString& type, const TQString& subResource );
- void fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>& map,
+ void fromKMailAsyncLoadResult( const TQMap<TQ_UINT32, TQString>& map,
const TQString& type,
const TQString& folder );
@@ -141,20 +141,20 @@ protected slots:
private:
void removeIncidences( const TQCString& incidenceType );
- void resolveConflict( KCal::Incidence*, const TQString& subresource, Q_UINT32 sernum );
+ void resolveConflict( KCal::Incidence*, const TQString& subresource, TQ_UINT32 sernum );
void addIncidence( const char* mimetype, const TQString& xml,
- const TQString& subResource, Q_UINT32 sernum );
+ const TQString& subResource, TQ_UINT32 sernum );
bool addIncidence( KCal::Incidence* i, const TQString& subresource,
- Q_UINT32 sernum );
+ TQ_UINT32 sernum );
/*
void addEvent( const TQString& xml, const TQString& subresource,
- Q_UINT32 sernum );
+ TQ_UINT32 sernum );
void addTodo( const TQString& xml, const TQString& subresource,
- Q_UINT32 sernum );
+ TQ_UINT32 sernum );
void addJournal( const TQString& xml, const TQString& subresource,
- Q_UINT32 sernum );
+ TQ_UINT32 sernum );
*/
bool loadAllEvents();
@@ -180,7 +180,7 @@ private:
Scalix::ResourceMap* subResourceMap( const TQString& contentsType );
bool sendKMailUpdate( KCal::IncidenceBase* incidence, const TQString& _subresource,
- Q_UINT32 sernum );
+ TQ_UINT32 sernum );
KCal::CalendarLocal mCalendar;
@@ -194,11 +194,11 @@ private:
ICalFormat mFormat;
/**
- This map contains the association between a new added incidence
+ This map tqcontains the association between a new added incidence
and the subresource it belongs to.
That's needed to return the correct mapping in subresourceIdentifier().
- We can't trust on mUidMap here, because it contains only non-pending uids.
+ We can't trust on mUidMap here, because it tqcontains only non-pending uids.
*/
TQMap<TQString, TQString> mNewIncidencesMap;
int mProgressDialogIncidenceLimit;
diff --git a/kresources/scalix/kioslave/scalix.cpp b/kresources/scalix/kioslave/scalix.cpp
index 043b0f4a..2a0c06cd 100644
--- a/kresources/scalix/kioslave/scalix.cpp
+++ b/kresources/scalix/kioslave/scalix.cpp
@@ -73,7 +73,7 @@ void Scalix::get( const KURL &url )
TQString path = url.path();
- if ( path.contains( "/freebusy/" ) ) {
+ if ( path.tqcontains( "/freebusy/" ) ) {
retrieveFreeBusy( url );
} else {
error( KIO::ERR_SLAVE_DEFINED, i18n( "Unknown path. Known path is '/freebusy/'" ) );
@@ -84,7 +84,7 @@ void Scalix::put( const KURL& url, int, bool, bool )
{
TQString path = url.path();
- if ( path.contains( "/freebusy/" ) ) {
+ if ( path.tqcontains( "/freebusy/" ) ) {
publishFreeBusy( url );
} else {
error( KIO::ERR_SLAVE_DEFINED, i18n( "Unknown path. Known path is '/freebusy/'" ) );
@@ -121,7 +121,7 @@ void Scalix::retrieveFreeBusy( const KURL &url )
connect( job, TQT_SIGNAL( result( KIO::Job* ) ),
this, TQT_SLOT( slotRetrieveResult( KIO::Job* ) ) );
- qApp->eventLoop()->enterLoop();
+ tqApp->eventLoop()->enterLoop();
}
void Scalix::publishFreeBusy( const KURL &url )
@@ -185,7 +185,7 @@ void Scalix::publishFreeBusy( const KURL &url )
connect( job, TQT_SIGNAL( result( KIO::Job* ) ),
this, TQT_SLOT( slotPublishResult( KIO::Job* ) ) );
- qApp->eventLoop()->enterLoop();
+ tqApp->eventLoop()->enterLoop();
}
void Scalix::slotInfoMessage( KIO::Job *job, const TQString &data )
@@ -208,7 +208,7 @@ void Scalix::slotRetrieveResult( KIO::Job *job )
finished();
}
- qApp->eventLoop()->exitLoop();
+ tqApp->eventLoop()->exitLoop();
}
void Scalix::slotPublishResult( KIO::Job *job )
@@ -219,7 +219,7 @@ void Scalix::slotPublishResult( KIO::Job *job )
finished();
}
- qApp->eventLoop()->exitLoop();
+ tqApp->eventLoop()->exitLoop();
}
#include "scalix.moc"
diff --git a/kresources/scalix/knotes/resourcescalix.cpp b/kresources/scalix/knotes/resourcescalix.cpp
index 2b789528..5afd6402 100644
--- a/kresources/scalix/knotes/resourcescalix.cpp
+++ b/kresources/scalix/knotes/resourcescalix.cpp
@@ -49,7 +49,7 @@ static const char* inlineMimeType = "text/calendar";
ResourceScalix::ResourceScalix( const KConfig *config )
: ResourceNotes( config ), ResourceScalixBase( "ResourceScalix-KNotes" ),
- mCalendar( TQString::fromLatin1("UTC") )
+ mCalendar( TQString::tqfromLatin1("UTC") )
{
setType( "scalix" );
}
@@ -99,7 +99,7 @@ bool ResourceScalix::loadSubResource( const TQString& subResource,
return false;
}
- TQMap<Q_UINT32, TQString> lst;
+ TQMap<TQ_UINT32, TQString> lst;
if( !kmailIncidences( lst, mimetype, subResource, 0, count ) ) {
kdError(5500) << "Communication problem in "
<< "ResourceScalix::getIncidenceList()\n";
@@ -111,7 +111,7 @@ bool ResourceScalix::loadSubResource( const TQString& subResource,
// Populate with the new entries
const bool silent = mSilent;
mSilent = true;
- TQMap<Q_UINT32, TQString>::Iterator it;
+ TQMap<TQ_UINT32, TQString>::Iterator it;
for ( it = lst.begin(); it != lst.end(); ++it ) {
KCal::Journal* journal = addNote( it.data(), subResource, it.key(), mimetype );
if ( !journal )
@@ -158,7 +158,7 @@ bool ResourceScalix::addNote( KCal::Journal* journal )
}
KCal::Journal* ResourceScalix::addNote( const TQString& data, const TQString& subresource,
- Q_UINT32 sernum, const TQString& )
+ TQ_UINT32 sernum, const TQString& )
{
KCal::Journal* journal = 0;
// FIXME: This does not take into account the time zone!
@@ -166,7 +166,7 @@ KCal::Journal* ResourceScalix::addNote( const TQString& data, const TQString& su
journal = static_cast<KCal::Journal*>( formatter.fromString( data ) );
Q_ASSERT( journal );
- if( journal && !mUidMap.contains( journal->uid() ) )
+ if( journal && !mUidMap.tqcontains( journal->uid() ) )
if ( addNote( journal, subresource, sernum ) )
return journal;
else
@@ -175,7 +175,7 @@ KCal::Journal* ResourceScalix::addNote( const TQString& data, const TQString& su
}
bool ResourceScalix::addNote( KCal::Journal* journal,
- const TQString& subresource, Q_UINT32 sernum )
+ const TQString& subresource, TQ_UINT32 sernum )
{
kdDebug(5500) << "ResourceScalix::addNote( KCal::Journal*, '" << subresource << "', " << sernum << " )\n";
@@ -212,7 +212,7 @@ bool ResourceScalix::addNote( KCal::Journal* journal,
bool ResourceScalix::deleteNote( KCal::Journal* journal )
{
const TQString uid = journal->uid();
- if ( !mUidMap.contains( uid ) )
+ if ( !mUidMap.tqcontains( uid ) )
// Odd
return false;
@@ -252,8 +252,8 @@ KCal::Alarm::List ResourceScalix::alarms( const TQDateTime& from, const TQDateTi
void ResourceScalix::incidenceUpdated( KCal::IncidenceBase* i )
{
TQString subResource;
- Q_UINT32 sernum;
- if ( mUidMap.contains( i->uid() ) ) {
+ TQ_UINT32 sernum;
+ if ( mUidMap.tqcontains( i->uid() ) ) {
subResource = mUidMap[ i->uid() ].resource();
sernum = mUidMap[ i->uid() ].serialNumber();
} else { // can this happen?
@@ -276,7 +276,7 @@ void ResourceScalix::incidenceUpdated( KCal::IncidenceBase* i )
*/
bool ResourceScalix::fromKMailAddIncidence( const TQString& type,
const TQString& subResource,
- Q_UINT32 sernum,
+ TQ_UINT32 sernum,
int,
const TQString& note )
{
@@ -327,7 +327,7 @@ void ResourceScalix::fromKMailAddSubresource( const TQString& type,
// Not ours
return;
- if ( mSubResources.contains( subResource ) )
+ if ( mSubResources.tqcontains( subResource ) )
// Already registered
return;
@@ -347,7 +347,7 @@ void ResourceScalix::fromKMailDelSubresource( const TQString& type,
// Not ours
return;
- if ( !mSubResources.contains( subResource ) )
+ if ( !mSubResources.tqcontains( subResource ) )
// Not registered
return;
@@ -383,7 +383,7 @@ void ResourceScalix::fromKMailDelSubresource( const TQString& type,
emit signalSubresourceRemoved( this, type, subResource );
}
-void ResourceScalix::fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>& map,
+void ResourceScalix::fromKMailAsyncLoadResult( const TQMap<TQ_UINT32, TQString>& map,
const TQString& type,
const TQString& folder )
{
@@ -393,7 +393,7 @@ void ResourceScalix::fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>&
const bool silent = mSilent;
mSilent = true;
TQString mimetype = inlineMimeType;
- for( TQMap<Q_UINT32, TQString>::ConstIterator it = map.begin(); it != map.end(); ++it ) {
+ for( TQMap<TQ_UINT32, TQString>::ConstIterator it = map.begin(); it != map.end(); ++it ) {
KCal::Journal* journal = addNote( it.data(), folder, it.key(), mimetype );
if ( !journal )
kdDebug(5500) << "loading note " << it.key() << " failed" << endl;
@@ -411,7 +411,7 @@ TQStringList ResourceScalix::subresources() const
bool ResourceScalix::subresourceActive( const TQString& res ) const
{
- if ( mSubResources.contains( res ) ) {
+ if ( mSubResources.tqcontains( res ) ) {
return mSubResources[ res ].active();
}
diff --git a/kresources/scalix/knotes/resourcescalix.h b/kresources/scalix/knotes/resourcescalix.h
index cb0c50fb..dc8517b6 100644
--- a/kresources/scalix/knotes/resourcescalix.h
+++ b/kresources/scalix/knotes/resourcescalix.h
@@ -80,7 +80,7 @@ public:
/// The ResourceScalixBase methods called by KMail
bool fromKMailAddIncidence( const TQString& type, const TQString& resource,
- Q_UINT32 sernum, int format, const TQString& note );
+ TQ_UINT32 sernum, int format, const TQString& note );
void fromKMailDelIncidence( const TQString& type, const TQString& resource,
const TQString& uid );
void fromKMailRefresh( const TQString& type, const TQString& resource );
@@ -90,7 +90,7 @@ public:
const TQString& label, bool writable );
void fromKMailDelSubresource( const TQString& type, const TQString& resource );
- void fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>& map,
+ void fromKMailAsyncLoadResult( const TQMap<TQ_UINT32, TQString>& map,
const TQString& type,
const TQString& folder );
@@ -106,9 +106,9 @@ signals:
private:
bool addNote( KCal::Journal* journal, const TQString& resource,
- Q_UINT32 sernum );
+ TQ_UINT32 sernum );
KCal::Journal* addNote( const TQString& data, const TQString& subresource,
- Q_UINT32 sernum, const TQString &mimetype );
+ TQ_UINT32 sernum, const TQString &mimetype );
bool loadSubResource( const TQString& resource, const TQString& mimetype );
diff --git a/kresources/scalix/scalixadmin/delegatedialog.cpp b/kresources/scalix/scalixadmin/delegatedialog.cpp
index 661f5743..d0a9644e 100644
--- a/kresources/scalix/scalixadmin/delegatedialog.cpp
+++ b/kresources/scalix/scalixadmin/delegatedialog.cpp
@@ -35,18 +35,18 @@ DelegateDialog::DelegateDialog( TQWidget *parent )
: KDialogBase( parent, "", true, "", Ok | Cancel, Ok, true )
{
TQWidget *page = new TQWidget( this );
- TQGridLayout *layout = new TQGridLayout( page, 5, 3, 11, 6 );
+ TQGridLayout *tqlayout = new TQGridLayout( page, 5, 3, 11, 6 );
TQLabel *label = new TQLabel( i18n( "User:" ), page );
- layout->addWidget( label, 0, 0 );
+ tqlayout->addWidget( label, 0, 0 );
mEmail = new TQLineEdit( page );
- layout->addWidget( mEmail, 0, 1 );
+ tqlayout->addWidget( mEmail, 0, 1 );
TQToolButton *emailSelector = new TQToolButton( page );
emailSelector->setUsesTextLabel( true );
emailSelector->setTextLabel( i18n( "..." ) );
- layout->addWidget( emailSelector, 0, 2 );
+ tqlayout->addWidget( emailSelector, 0, 2 );
TQValueList<Scalix::DelegateTypes> types;
types << Scalix::SendOnBehalfOf;
@@ -57,7 +57,7 @@ DelegateDialog::DelegateDialog( TQWidget *parent )
int row = 1;
for ( uint i = 0; i < types.count(); ++i ) {
TQCheckBox *box = new TQCheckBox( Scalix::Delegate::rightsAsString( types[ i ] ), page );
- layout->addMultiCellWidget( box, row, row, 1, 2 );
+ tqlayout->addMultiCellWidget( box, row, row, 1, 2 );
mRights.insert( types[ i ], box );
row++;
diff --git a/kresources/scalix/scalixadmin/delegatepage.cpp b/kresources/scalix/scalixadmin/delegatepage.cpp
index 03347290..32b29d46 100644
--- a/kresources/scalix/scalixadmin/delegatepage.cpp
+++ b/kresources/scalix/scalixadmin/delegatepage.cpp
@@ -37,21 +37,21 @@
DelegatePage::DelegatePage( TQWidget *parent )
: TQWidget( parent )
{
- TQGridLayout *layout = new TQGridLayout( this, 2, 3, 11, 6 );
+ TQGridLayout *tqlayout = new TQGridLayout( this, 2, 3, 11, 6 );
mView = new DelegateView( &mManager, this );
- layout->addMultiCellWidget( mView, 0, 0, 0, 2 );
+ tqlayout->addMultiCellWidget( mView, 0, 0, 0, 2 );
mAddButton = new TQPushButton( i18n( "Add Delegate..." ), this );
- layout->addWidget( mAddButton, 1, 0 );
+ tqlayout->addWidget( mAddButton, 1, 0 );
mEditButton = new TQPushButton( i18n( "Edit Delegate..." ), this );
mEditButton->setEnabled( false );
- layout->addWidget( mEditButton, 1, 1 );
+ tqlayout->addWidget( mEditButton, 1, 1 );
mRemoveButton = new TQPushButton( i18n( "Remove Delegate" ), this );
mRemoveButton->setEnabled( false );
- layout->addWidget( mRemoveButton, 1, 2 );
+ tqlayout->addWidget( mRemoveButton, 1, 2 );
connect( mView, TQT_SIGNAL( selectionChanged() ), TQT_SLOT( selectionChanged() ) );
connect( mAddButton, TQT_SIGNAL( clicked() ), TQT_SLOT( addDelegate() ) );
diff --git a/kresources/scalix/scalixadmin/otherusermanager.cpp b/kresources/scalix/scalixadmin/otherusermanager.cpp
index a3c19de1..cacb9474 100644
--- a/kresources/scalix/scalixadmin/otherusermanager.cpp
+++ b/kresources/scalix/scalixadmin/otherusermanager.cpp
@@ -30,7 +30,7 @@ OtherUserManager::~OtherUserManager()
void OtherUserManager::addOtherUser( const TQString &email )
{
- if ( !mOtherUsers.contains( email ) ) {
+ if ( !mOtherUsers.tqcontains( email ) ) {
mOtherUsers.append( email );
emit changed();
}
diff --git a/kresources/scalix/scalixadmin/otheruserpage.cpp b/kresources/scalix/scalixadmin/otheruserpage.cpp
index 8570cab0..f7a9ee63 100644
--- a/kresources/scalix/scalixadmin/otheruserpage.cpp
+++ b/kresources/scalix/scalixadmin/otheruserpage.cpp
@@ -40,17 +40,17 @@
OtherUserPage::OtherUserPage( TQWidget *parent )
: TQWidget( parent )
{
- TQGridLayout *layout = new TQGridLayout( this, 2, 2, 11, 6 );
+ TQGridLayout *tqlayout = new TQGridLayout( this, 2, 2, 11, 6 );
mView = new OtherUserView( &mManager, this );
- layout->addMultiCellWidget( mView, 0, 0, 0, 1 );
+ tqlayout->addMultiCellWidget( mView, 0, 0, 0, 1 );
mAddButton = new TQPushButton( i18n( "Add Account..." ), this );
- layout->addWidget( mAddButton, 1, 0 );
+ tqlayout->addWidget( mAddButton, 1, 0 );
mDeleteButton = new TQPushButton( i18n( "Remove Account" ), this );
mDeleteButton->setEnabled( false );
- layout->addWidget( mDeleteButton, 1, 1 );
+ tqlayout->addWidget( mDeleteButton, 1, 1 );
connect( mView, TQT_SIGNAL( selectionChanged() ), TQT_SLOT( selectionChanged() ) );
connect( mAddButton, TQT_SIGNAL( clicked() ), TQT_SLOT( addUser() ) );
@@ -139,12 +139,12 @@ void OtherUserPage::selectionChanged()
void OtherUserPage::updateKmail()
{
- TQMessageBox *msg = new TQMessageBox( qApp->mainWidget() );
+ TQMessageBox *msg = new TQMessageBox( tqApp->mainWidget() );
msg->setText( i18n( "Updating account..." ) );
msg->show();
- qApp->processEvents();
+ tqApp->processEvents();
sleep( 1 );
- qApp->processEvents();
+ tqApp->processEvents();
TQString error;
TQCString dcopService;
diff --git a/kresources/scalix/scalixadmin/outofofficepage.cpp b/kresources/scalix/scalixadmin/outofofficepage.cpp
index e1e331fc..401d4de1 100644
--- a/kresources/scalix/scalixadmin/outofofficepage.cpp
+++ b/kresources/scalix/scalixadmin/outofofficepage.cpp
@@ -36,7 +36,7 @@
OutOfOfficePage::OutOfOfficePage( TQWidget *parent )
: TQWidget( parent )
{
- TQGridLayout *layout = new TQGridLayout( this, 4, 2, 11, 6 );
+ TQGridLayout *tqlayout = new TQGridLayout( this, 4, 2, 11, 6 );
TQButtonGroup *group = new TQButtonGroup( 1, Qt::Vertical, this );
@@ -48,10 +48,10 @@ OutOfOfficePage::OutOfOfficePage( TQWidget *parent )
mMessage = new TQTextEdit( this );
mSaveButton = new TQPushButton( i18n( "Save" ), this );
- layout->addMultiCellWidget( group, 0, 0, 0, 1 );
- layout->addMultiCellWidget( mLabel, 1, 1, 0, 1 );
- layout->addMultiCellWidget( mMessage, 2, 2, 0, 1 );
- layout->addWidget( mSaveButton, 3, 1 );
+ tqlayout->addMultiCellWidget( group, 0, 0, 0, 1 );
+ tqlayout->addMultiCellWidget( mLabel, 1, 1, 0, 1 );
+ tqlayout->addMultiCellWidget( mMessage, 2, 2, 0, 1 );
+ tqlayout->addWidget( mSaveButton, 3, 1 );
statusChanged();
diff --git a/kresources/scalix/scalixadmin/passwordpage.cpp b/kresources/scalix/scalixadmin/passwordpage.cpp
index facc2917..e75d3fdd 100644
--- a/kresources/scalix/scalixadmin/passwordpage.cpp
+++ b/kresources/scalix/scalixadmin/passwordpage.cpp
@@ -38,29 +38,29 @@
PasswordPage::PasswordPage( TQWidget *parent )
: TQWidget( parent ), mJob( 0 )
{
- TQGridLayout *layout = new TQGridLayout( this, 2, 3, 11, 6 );
+ TQGridLayout *tqlayout = new TQGridLayout( this, 2, 3, 11, 6 );
TQLabel *label = new TQLabel( i18n( "New password:" ), this );
- layout->addWidget( label, 0, 0 );
+ tqlayout->addWidget( label, 0, 0 );
mPassword = new TQLineEdit( this );
mPassword->setEchoMode( TQLineEdit::Password );
label->setBuddy( mPassword );
- layout->addWidget( mPassword, 0, 1 );
+ tqlayout->addWidget( mPassword, 0, 1 );
label = new TQLabel( i18n( "Retype new password:" ), this );
- layout->addWidget( label, 1, 0 );
+ tqlayout->addWidget( label, 1, 0 );
mPasswordRetype = new TQLineEdit( this );
mPasswordRetype->setEchoMode( TQLineEdit::Password );
label->setBuddy( mPasswordRetype );
- layout->addWidget( mPasswordRetype, 1, 1 );
+ tqlayout->addWidget( mPasswordRetype, 1, 1 );
mButton = new TQPushButton( i18n( "Change" ), this );
mButton->setEnabled( false );
- layout->addWidget( mButton, 2, 1 );
+ tqlayout->addWidget( mButton, 2, 1 );
- layout->setRowSpacing( 3, 1 );
+ tqlayout->setRowSpacing( 3, 1 );
connect( mPassword, TQT_SIGNAL( textChanged( const TQString& ) ), this, TQT_SLOT( textChanged() ) );
connect( mPasswordRetype, TQT_SIGNAL( textChanged( const TQString& ) ), this, TQT_SLOT( textChanged() ) );
@@ -165,8 +165,8 @@ void PasswordPage::finished( KIO::Job* job )
// First try to store in KWallet
if ( KWallet::Wallet::isEnabled() ) {
WId window = 0;
- if ( qApp->activeWindow() )
- window = qApp->activeWindow()->winId();
+ if ( tqApp->activeWindow() )
+ window = tqApp->activeWindow()->winId();
KWallet::Wallet *wallet = KWallet::Wallet::openWallet( KWallet::Wallet::NetworkWallet(), window );
if ( wallet ) {
diff --git a/kresources/scalix/shared/kmailconnection.cpp b/kresources/scalix/shared/kmailconnection.cpp
index b4b4b9eb..60ea25ee 100644
--- a/kresources/scalix/shared/kmailconnection.cpp
+++ b/kresources/scalix/shared/kmailconnection.cpp
@@ -88,8 +88,8 @@ bool KMailConnection::connectToKMail()
dcopService, dcopObjectId );
// Attach to the KMail signals
- if ( !connectKMailSignal( "incidenceAdded(TQString,TQString,Q_UINT32,int,TQString)",
- "fromKMailAddIncidence(TQString,TQString,Q_UINT32,int,TQString)" ) )
+ if ( !connectKMailSignal( "incidenceAdded(TQString,TQString,TQ_UINT32,int,TQString)",
+ "fromKMailAddIncidence(TQString,TQString,TQ_UINT32,int,TQString)" ) )
kdError(5650) << "DCOP connection to incidenceAdded failed" << endl;
if ( !connectKMailSignal( "incidenceDeleted(TQString,TQString,TQString)",
"fromKMailDelIncidence(TQString,TQString,TQString)" ) )
@@ -103,8 +103,8 @@ bool KMailConnection::connectToKMail()
if ( !connectKMailSignal( "subresourceDeleted(TQString,TQString)",
"fromKMailDelSubresource(TQString,TQString)" ) )
kdError(5650) << "DCOP connection to subresourceDeleted failed" << endl;
- if ( !connectKMailSignal( "asyncLoadResult(TQMap<Q_UINT32, TQString>, TQString, TQString)",
- "fromKMailAsyncLoadResult(TQMap<Q_UINT32, TQString>, TQString, TQString)" ) )
+ if ( !connectKMailSignal( "asyncLoadResult(TQMap<TQ_UINT32, TQString>, TQString, TQString)",
+ "fromKMailAsyncLoadResult(TQMap<TQ_UINT32, TQString>, TQString, TQString)" ) )
kdError(5650) << "DCOP connection to asyncLoadResult failed" << endl;
}
@@ -113,7 +113,7 @@ bool KMailConnection::connectToKMail()
bool KMailConnection::fromKMailAddIncidence( const TQString& type,
const TQString& folder,
- Q_UINT32 sernum,
+ TQ_UINT32 sernum,
int format,
const TQString& data )
{
@@ -164,7 +164,7 @@ void KMailConnection::fromKMailDelSubresource( const TQString& type,
mResource->fromKMailDelSubresource( type, resource );
}
-void KMailConnection::fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>& map,
+void KMailConnection::fromKMailAsyncLoadResult( const TQMap<TQ_UINT32, TQString>& map,
const TQString& type,
const TQString& folder )
{
@@ -199,7 +199,7 @@ bool KMailConnection::kmailIncidencesCount( int& count,
return mKMailIcalIfaceStub->ok();
}
-bool KMailConnection::kmailIncidences( TQMap<Q_UINT32, TQString>& lst,
+bool KMailConnection::kmailIncidences( TQMap<TQ_UINT32, TQString>& lst,
const TQString& mimetype,
const TQString& resource,
int startIndex,
@@ -215,7 +215,7 @@ bool KMailConnection::kmailIncidences( TQMap<Q_UINT32, TQString>& lst,
bool KMailConnection::kmailGetAttachment( KURL& url,
const TQString& resource,
- Q_UINT32 sernum,
+ TQ_UINT32 sernum,
const TQString& filename )
{
if ( !connectToKMail() )
@@ -226,7 +226,7 @@ bool KMailConnection::kmailGetAttachment( KURL& url,
}
bool KMailConnection::kmailDeleteIncidence( const TQString& resource,
- Q_UINT32 sernum )
+ TQ_UINT32 sernum )
{
return connectToKMail()
&& mKMailIcalIfaceStub->deleteIncidenceKolab( resource, sernum )
@@ -234,7 +234,7 @@ bool KMailConnection::kmailDeleteIncidence( const TQString& resource,
}
bool KMailConnection::kmailUpdate( const TQString& resource,
- Q_UINT32& sernum,
+ TQ_UINT32& sernum,
const TQString& subject,
const TQString& plainTextBody,
const TQMap<TQCString, TQString>& customHeaders,
diff --git a/kresources/scalix/shared/kmailconnection.h b/kresources/scalix/shared/kmailconnection.h
index bd02d7bb..3d34d5c6 100644
--- a/kresources/scalix/shared/kmailconnection.h
+++ b/kresources/scalix/shared/kmailconnection.h
@@ -54,13 +54,13 @@ class KMailConnection : public TQObject, public DCOPObject {
// These are the methods called by KMail when the resource changes
k_dcop:
bool fromKMailAddIncidence( const TQString& type, const TQString& resource,
- Q_UINT32 sernum, int format, const TQString& xml );
+ TQ_UINT32 sernum, int format, const TQString& xml );
void fromKMailDelIncidence( const TQString& type, const TQString& resource,
const TQString& xml );
void fromKMailRefresh( const TQString& type, const TQString& resource );
void fromKMailAddSubresource( const TQString& type, const TQString& resource, const TQString& label );
void fromKMailDelSubresource( const TQString& type, const TQString& resource );
- void fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>& map, const TQString& type,
+ void fromKMailAsyncLoadResult( const TQMap<TQ_UINT32, TQString>& map, const TQString& type,
const TQString& folder );
public:
@@ -78,16 +78,16 @@ public:
bool kmailIncidencesCount( int& count,
const TQString& mimetype,
const TQString& resource );
- bool kmailIncidences( TQMap<Q_UINT32, TQString>& lst, const TQString& mimetype,
+ bool kmailIncidences( TQMap<TQ_UINT32, TQString>& lst, const TQString& mimetype,
const TQString& resource,
int startIndex,
int nbMessages );
- bool kmailGetAttachment( KURL& url, const TQString& resource, Q_UINT32 sernum,
+ bool kmailGetAttachment( KURL& url, const TQString& resource, TQ_UINT32 sernum,
const TQString& filename );
- bool kmailDeleteIncidence( const TQString& resource, Q_UINT32 sernum );
+ bool kmailDeleteIncidence( const TQString& resource, TQ_UINT32 sernum );
bool kmailUpdate( const TQString& resource,
- Q_UINT32& sernum,
+ TQ_UINT32& sernum,
const TQString& subject,
const TQString& plainTextBody,
const TQMap<TQCString, TQString>& customHeaders,
diff --git a/kresources/scalix/shared/resourcescalixbase.cpp b/kresources/scalix/shared/resourcescalixbase.cpp
index e239bfb3..9bd0afb8 100644
--- a/kresources/scalix/shared/resourcescalixbase.cpp
+++ b/kresources/scalix/shared/resourcescalixbase.cpp
@@ -82,7 +82,7 @@ bool ResourceScalixBase::kmailIncidencesCount( int &count,
return mConnection->kmailIncidencesCount( count, mimetype, resource );
}
-bool ResourceScalixBase::kmailIncidences( TQMap<Q_UINT32, TQString>& lst,
+bool ResourceScalixBase::kmailIncidences( TQMap<TQ_UINT32, TQString>& lst,
const TQString& mimetype,
const TQString& resource,
int startIndex,
@@ -92,20 +92,20 @@ bool ResourceScalixBase::kmailIncidences( TQMap<Q_UINT32, TQString>& lst,
}
bool ResourceScalixBase::kmailGetAttachment( KURL& url, const TQString& resource,
- Q_UINT32 sernum,
+ TQ_UINT32 sernum,
const TQString& filename ) const
{
return mConnection->kmailGetAttachment( url, resource, sernum, filename );
}
bool ResourceScalixBase::kmailDeleteIncidence( const TQString& resource,
- Q_UINT32 sernum )
+ TQ_UINT32 sernum )
{
return mSilent || mConnection->kmailDeleteIncidence( resource, sernum );
}
bool ResourceScalixBase::kmailUpdate( const TQString& resource,
- Q_UINT32& sernum,
+ TQ_UINT32& sernum,
const TQString& xml,
const TQString& mimetype,
const TQString& subject,
diff --git a/kresources/scalix/shared/resourcescalixbase.h b/kresources/scalix/shared/resourcescalixbase.h
index 803ac47b..e402e427 100644
--- a/kresources/scalix/shared/resourcescalixbase.h
+++ b/kresources/scalix/shared/resourcescalixbase.h
@@ -78,7 +78,7 @@ public:
// These are the methods called by KMail when the resource changes
virtual bool fromKMailAddIncidence( const TQString& type,
const TQString& resource,
- Q_UINT32 sernum,
+ TQ_UINT32 sernum,
int format,
const TQString& data ) = 0;
virtual void fromKMailDelIncidence( const TQString& type,
@@ -93,7 +93,7 @@ public:
virtual void fromKMailDelSubresource( const TQString& type,
const TQString& resource ) = 0;
- virtual void fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>& map,
+ virtual void fromKMailAsyncLoadResult( const TQMap<TQ_UINT32, TQString>& map,
const TQString& type,
const TQString& folder ) = 0;
protected:
@@ -115,7 +115,7 @@ protected:
/// Get the mimetype attachments from a chunk of messages from this folder.
/// Returns a TQMap with serialNumber/attachment pairs.
- bool kmailIncidences( TQMap<Q_UINT32, TQString>& lst, const TQString& mimetype,
+ bool kmailIncidences( TQMap<TQ_UINT32, TQString>& lst, const TQString& mimetype,
const TQString& resource,
int startIndex,
int nbMessages ) const;
@@ -127,12 +127,12 @@ public: // for Contact
/// be called by the resource after obtaining the incidence.
/// The resource must delete the temp file.
bool kmailGetAttachment( KURL& url, const TQString& resource,
- Q_UINT32 sernum,
+ TQ_UINT32 sernum,
const TQString& filename ) const;
protected:
/// Delete an incidence.
- bool kmailDeleteIncidence( const TQString& resource, Q_UINT32 sernum );
+ bool kmailDeleteIncidence( const TQString& resource, TQ_UINT32 sernum );
KMailICalIface::StorageFormat kmailStorageFormat( const TQString& folder ) const;
@@ -140,7 +140,7 @@ protected:
/// Update an incidence. The list of attachments are URLs.
/// The parameter sernum is updated with the right KMail serial number
- bool kmailUpdate( const TQString& resource, Q_UINT32& sernum,
+ bool kmailUpdate( const TQString& resource, TQ_UINT32& sernum,
const TQString& xml,
const TQString& mimetype,
const TQString& subject,
diff --git a/kresources/scalix/shared/scalixbase.cpp b/kresources/scalix/shared/scalixbase.cpp
index 8fb5177b..e9a5ab8c 100644
--- a/kresources/scalix/shared/scalixbase.cpp
+++ b/kresources/scalix/shared/scalixbase.cpp
@@ -42,8 +42,8 @@ using namespace Scalix;
ScalixBase::ScalixBase( const TQString& tz )
- : mCreationDate( TQDateTime::currentDateTime() ),
- mLastModified( TQDateTime::currentDateTime() ),
+ : mCreationDate( TQDateTime::tqcurrentDateTime() ),
+ mLastModified( TQDateTime::tqcurrentDateTime() ),
mSensitivity( Public ), mTimeZoneId( tz ),
mHasPilotSyncId( false ), mHasPilotSyncStatus( false )
{
@@ -92,7 +92,7 @@ void ScalixBase::setFields( const KABC::Addressee* addressee )
kdDebug(5006) << "Creation time string: " << creationString << endl;
TQDateTime creationDate;
if ( creationString.isEmpty() ) {
- creationDate = TQDateTime::currentDateTime();
+ creationDate = TQDateTime::tqcurrentDateTime();
kdDebug(5006) << "Creation date set to current time\n";
}
else {
@@ -101,7 +101,7 @@ void ScalixBase::setFields( const KABC::Addressee* addressee )
}
TQDateTime modified = addressee->revision();
if ( !modified.isValid() )
- modified = TQDateTime::currentDateTime();
+ modified = TQDateTime::tqcurrentDateTime();
setLastModified( modified );
if ( modified < creationDate ) {
// It's not possible that the modification date is earlier than creation
diff --git a/kresources/scalix/shared/subresource.cpp b/kresources/scalix/shared/subresource.cpp
index 0acfb081..02c9e40f 100644
--- a/kresources/scalix/shared/subresource.cpp
+++ b/kresources/scalix/shared/subresource.cpp
@@ -86,7 +86,7 @@ int SubResource::completionWeight() const
return mCompletionWeight;
}
-StorageReference::StorageReference( const TQString& resource, Q_UINT32 sernum )
+StorageReference::StorageReference( const TQString& resource, TQ_UINT32 sernum )
: mResource( resource ), mSerialNumber( sernum )
{
}
@@ -105,12 +105,12 @@ TQString StorageReference::resource() const
return mResource;
}
-void StorageReference::setSerialNumber( Q_UINT32 serialNumber )
+void StorageReference::setSerialNumber( TQ_UINT32 serialNumber )
{
mSerialNumber = serialNumber;
}
-Q_UINT32 StorageReference::serialNumber() const
+TQ_UINT32 StorageReference::serialNumber() const
{
return mSerialNumber;
}
diff --git a/kresources/scalix/shared/subresource.h b/kresources/scalix/shared/subresource.h
index f7898c14..d7c575da 100644
--- a/kresources/scalix/shared/subresource.h
+++ b/kresources/scalix/shared/subresource.h
@@ -89,18 +89,18 @@ public:
// Just for QMap
StorageReference() {}
- StorageReference( const TQString& resource, Q_UINT32 sernum );
+ StorageReference( const TQString& resource, TQ_UINT32 sernum );
virtual ~StorageReference();
virtual void setResource( const TQString& resource );
virtual TQString resource() const;
- virtual void setSerialNumber( Q_UINT32 serialNumber );
- virtual Q_UINT32 serialNumber() const;
+ virtual void setSerialNumber( TQ_UINT32 serialNumber );
+ virtual TQ_UINT32 serialNumber() const;
private:
TQString mResource;
- Q_UINT32 mSerialNumber;
+ TQ_UINT32 mSerialNumber;
};
typedef TQMap<TQString, StorageReference> UidMap;
diff --git a/kresources/scalix/kcal/resourcescalix.cpp b/kresources/scalix/kcal/resourcescalix.cpp
index 63e964eb..1d74c570 100644
--- a/kresources/scalix/kcal/resourcescalix.cpp
+++ b/kresources/scalix/kcal/resourcescalix.cpp
@@ -63,7 +63,7 @@ static const char* incidenceInlineMimeType = "text/calendar";
ResourceScalix::ResourceScalix( const KConfig *config )
: ResourceCalendar( config ), ResourceScalixBase( "ResourceScalix-libkcal" ),
- mCalendar( TQString::fromLatin1("UTC") ), mOpen( false )
+ mCalendar( TQString::tqfromLatin1("UTC") ), mOpen( false )
{
setType( "scalix" );
connect( &mResourceChangedTimer, TQT_SIGNAL( timeout() ),
@@ -159,7 +159,7 @@ bool ResourceScalix::loadSubResource( const TQString& subResource,
const TQString labelTxt = !strcmp(mimetype, "application/x-vnd.kolab.task") ? i18n( "Loading tasks..." )
: !strcmp(mimetype, "application/x-vnd.kolab.journal") ? i18n( "Loading journals..." )
: i18n( "Loading events..." );
- const bool useProgress = qApp && qApp->type() != TQApplication::Tty && count > mProgressDialogIncidenceLimit;
+ const bool useProgress = tqApp && tqApp->type() != TQApplication::Tty && count > mProgressDialogIncidenceLimit;
if ( useProgress )
(void)::Observer::self(); // ensure kio_uiserver is running
UIServer_stub uiserver( "kio_uiserver", "UIServer" );
@@ -172,7 +172,7 @@ bool ResourceScalix::loadSubResource( const TQString& subResource,
}
for ( int startIndex = 0; startIndex < count; startIndex += nbMessages ) {
- TQMap<Q_UINT32, TQString> lst;
+ TQMap<TQ_UINT32, TQString> lst;
if ( !kmailIncidences( lst, mimetype, subResource, startIndex, nbMessages ) ) {
kdError(5650) << "Communication problem in ResourceScalix::load()\n";
if ( progressId )
@@ -182,7 +182,7 @@ bool ResourceScalix::loadSubResource( const TQString& subResource,
{ // for RAII scoping below
TemporarySilencer t( this );
- for( TQMap<Q_UINT32, TQString>::ConstIterator it = lst.begin(); it != lst.end(); ++it ) {
+ for( TQMap<TQ_UINT32, TQString>::ConstIterator it = lst.begin(); it != lst.end(); ++it ) {
addIncidence( mimetype, it.data(), subResource, it.key() );
}
}
@@ -269,24 +269,24 @@ void ResourceScalix::incidenceUpdated( KCal::IncidenceBase* incidencebase )
{
if ( incidencebase->isReadOnly() ) return; // Should not happen (TM)
incidencebase->setSyncStatus( KCal::Event::SYNCMOD );
- incidencebase->setLastModified( TQDateTime::currentDateTime() );
+ incidencebase->setLastModified( TQDateTime::tqcurrentDateTime() );
// we should probably update the revision number here,
// or internally in the Event itself when certain things change.
// need to verify with ical documentation.
const TQString uid = incidencebase->uid();
- if ( mUidsPendingUpdate.contains( uid ) || mUidsPendingAdding.contains( uid ) ) {
+ if ( mUidsPendingUpdate.tqcontains( uid ) || mUidsPendingAdding.tqcontains( uid ) ) {
/* We are currently processing this event ( removing and readding or
* adding it ). If so, ignore this update. Keep the last of these around
* and process once we hear back from KMail on this event. */
- mPendingUpdates.replace( uid, incidencebase );
+ mPendingUpdates.tqreplace( uid, incidencebase );
return;
}
TQString subResource;
- Q_UINT32 sernum = 0;
- if ( mUidMap.contains( uid ) ) {
+ TQ_UINT32 sernum = 0;
+ if ( mUidMap.tqcontains( uid ) ) {
subResource = mUidMap[ uid ].resource();
sernum = mUidMap[ uid ].serialNumber();
mUidsPendingUpdate.append( uid );
@@ -294,7 +294,7 @@ void ResourceScalix::incidenceUpdated( KCal::IncidenceBase* incidencebase )
sendKMailUpdate( incidencebase, subResource, sernum );
}
-void ResourceScalix::resolveConflict( KCal::Incidence* inc, const TQString& subresource, Q_UINT32 sernum )
+void ResourceScalix::resolveConflict( KCal::Incidence* inc, const TQString& subresource, TQ_UINT32 sernum )
{
if ( ! inc )
return;
@@ -344,7 +344,7 @@ void ResourceScalix::resolveConflict( KCal::Incidence* inc, const TQString& subr
}
}
void ResourceScalix::addIncidence( const char* mimetype, const TQString& data,
- const TQString& subResource, Q_UINT32 sernum )
+ const TQString& subResource, TQ_UINT32 sernum )
{
// This uses pointer comparison, so it only works if we use the static
// objects defined in the top of the file
@@ -354,7 +354,7 @@ void ResourceScalix::addIncidence( const char* mimetype, const TQString& data,
bool ResourceScalix::sendKMailUpdate( KCal::IncidenceBase* incidencebase, const TQString& subresource,
- Q_UINT32 sernum )
+ TQ_UINT32 sernum )
{
const TQString& type = incidencebase->type();
const char* mimetype = 0;
@@ -390,14 +390,14 @@ bool ResourceScalix::sendKMailUpdate( KCal::IncidenceBase* incidencebase, const
// behold, sernum is an in-parameter
const bool rc = kmailUpdate( subresource, sernum, data, mimetype, subject, customHeaders );
// update the serial number
- if ( mUidMap.contains( incidencebase->uid() ) ) {
+ if ( mUidMap.tqcontains( incidencebase->uid() ) ) {
mUidMap[ incidencebase->uid() ].setSerialNumber( sernum );
}
return rc;
}
bool ResourceScalix::addIncidence( KCal::Incidence* incidence, const TQString& _subresource,
- Q_UINT32 sernum )
+ TQ_UINT32 sernum )
{
Q_ASSERT( incidence );
if ( !incidence ) return false;
@@ -450,7 +450,7 @@ bool ResourceScalix::addIncidence( KCal::Incidence* incidence, const TQString& _
* We know the new state, so lets just not do much at all. The old incidence
* in the calendar remains valid, but the serial number changed, so we need to
* update that */
- if ( ourOwnUpdate = mUidsPendingUpdate.contains( uid ) ) {
+ if ( ourOwnUpdate = mUidsPendingUpdate.tqcontains( uid ) ) {
mUidsPendingUpdate.remove( uid );
mUidMap.remove( uid );
mUidMap[ uid ] = StorageReference( subResource, sernum );
@@ -460,7 +460,7 @@ bool ResourceScalix::addIncidence( KCal::Incidence* incidence, const TQString& _
* unless the folder is read-only, in which case the user should not be
* offered a means of putting mails in a folder she'll later be unable to
* upload. Skip the incidence, in this case. */
- if ( mUidMap.contains( uid )
+ if ( mUidMap.tqcontains( uid )
&& ( mUidMap[ uid ].resource() == subResource ) ) {
if ( (*map)[ subResource ].writable() ) {
resolveConflict( incidence, subResource, sernum );
@@ -472,7 +472,7 @@ bool ResourceScalix::addIncidence( KCal::Incidence* incidence, const TQString& _
}
/* Add to the cache if the add didn't come from KOrganizer, in which case
* we've already added it, and listen to updates from KOrganizer for it. */
- if ( !mUidsPendingAdding.contains( uid ) ) {
+ if ( !mUidsPendingAdding.tqcontains( uid ) ) {
mCalendar.addIncidence( incidence );
incidence->registerObserver( this );
}
@@ -489,7 +489,7 @@ bool ResourceScalix::addIncidence( KCal::Incidence* incidence, const TQString& _
} else {
/* If the uid was added by KMail, KOrganizer needs to be told, so
* schedule emitting of the resourceChanged signal. */
- if ( !mUidsPendingAdding.contains( uid ) ) {
+ if ( !mUidsPendingAdding.tqcontains( uid ) ) {
if ( !ourOwnUpdate ) mResourceChangedTimer.changeInterval( 100 );
} else {
mUidsPendingAdding.remove( uid );
@@ -504,7 +504,7 @@ bool ResourceScalix::addIncidence( KCal::Incidence* incidence, const TQString& _
bool ResourceScalix::addEvent( KCal::Event* event )
{
- if ( mUidMap.contains( event->uid() ) )
+ if ( mUidMap.tqcontains( event->uid() ) )
return true; //noop
else
return addIncidence( event, TQString::null, 0 );
@@ -521,7 +521,7 @@ bool ResourceScalix::deleteIncidence( KCal::Incidence* incidence )
if ( incidence->isReadOnly() ) return false;
const TQString uid = incidence->uid();
- if( !mUidMap.contains( uid ) ) return false; // Odd
+ if( !mUidMap.tqcontains( uid ) ) return false; // Odd
/* The user told us to delete, tell KMail */
if ( !mSilent ) {
kmailDeleteIncidence( mUidMap[ uid ].resource(),
@@ -572,7 +572,7 @@ KCal::Event::List ResourceScalix::rawEvents( const TQDate& start,
bool ResourceScalix::addTodo( KCal::Todo* todo )
{
- if ( mUidMap.contains( todo->uid() ) )
+ if ( mUidMap.tqcontains( todo->uid() ) )
return true; //noop
else
return addIncidence( todo, TQString::null, 0 );
@@ -606,7 +606,7 @@ KCal::Todo::List ResourceScalix::rawTodosForDate( const TQDate& date )
bool ResourceScalix::addJournal( KCal::Journal* journal )
{
- if ( mUidMap.contains( journal->uid() ) )
+ if ( mUidMap.tqcontains( journal->uid() ) )
return true; //noop
else
return addIncidence( journal, TQString::null, 0 );
@@ -657,7 +657,7 @@ void ResourceScalix::setTimeZoneId( const TQString& tzid )
bool ResourceScalix::fromKMailAddIncidence( const TQString& type,
const TQString& subResource,
- Q_UINT32 sernum,
+ TQ_UINT32 sernum,
int /*format*/,
const TQString& data )
{
@@ -689,11 +689,11 @@ void ResourceScalix::fromKMailDelIncidence( const TQString& type,
if ( !subresourceActive( subResource ) ) return;
// Can't be in both, by contract
- if ( mUidsPendingDeletion.contains( uid ) ) {
+ if ( mUidsPendingDeletion.tqcontains( uid ) ) {
mUidsPendingDeletion.remove( uid );
- } else if ( mUidsPendingUpdate.contains( uid ) ) {
+ } else if ( mUidsPendingUpdate.tqcontains( uid ) ) {
// It's good to know if was deleted, but we are waiting on a new one to
// replace it, so let's just sit tight.
} else {
// We didn't trigger this, so KMail did, remove the reference to the uid
KCal::Incidence* incidence = mCalendar.incidence( uid );
@@ -741,7 +741,7 @@ void ResourceScalix::fromKMailAddSubresource( const TQString& type,
// Not ours
return;
- if ( map->contains( subResource ) )
+ if ( map->tqcontains( subResource ) )
// Already registered
return;
@@ -760,7 +760,7 @@ void ResourceScalix::fromKMailDelSubresource( const TQString& type,
ResourceMap* map = subResourceMap( type );
if ( !map ) // not ours
return;
- if ( map->contains( subResource ) )
+ if ( map->tqcontains( subResource ) )
map->erase( subResource );
else
// Not registered
@@ -807,11 +807,11 @@ TQStringList ResourceScalix::subresources() const
const QString
ResourceScalix::labelForSubresource( const TQString& subresource ) const
{
- if ( mEventSubResources.contains( subresource ) )
+ if ( mEventSubResources.tqcontains( subresource ) )
return mEventSubResources[ subresource ].label();
- if ( mTodoSubResources.contains( subresource ) )
+ if ( mTodoSubResources.tqcontains( subresource ) )
return mTodoSubResources[ subresource ].label();
- if ( mJournalSubResources.contains( subresource ) )
+ if ( mJournalSubResources.tqcontains( subresource ) )
return mJournalSubResources[ subresource ].label();
return subresource;
}
@@ -819,21 +819,21 @@ ResourceScalix::labelForSubresource( const TQString& subresource ) const
TQString ResourceScalix::subresourceIdentifier( Incidence *incidence )
{
TQString uid = incidence->uid();
- if ( mUidMap.contains( uid ) )
+ if ( mUidMap.tqcontains( uid ) )
return mUidMap[ uid ].resource();
else
- if ( mNewIncidencesMap.contains( uid ) )
+ if ( mNewIncidencesMap.tqcontains( uid ) )
return mNewIncidencesMap[ uid ];
else
return TQString();
}
-void ResourceScalix::fromKMailAsyncLoadResult( const TQMap<Q_UINT32, TQString>& map,
+void ResourceScalix::fromKMailAsyncLoadResult( const TQMap<TQ_UINT32, TQString>& map,
const TQString& type,
const TQString& folder )
{
TemporarySilencer t( this );
- for( TQMap<Q_UINT32, TQString>::ConstIterator it = map.begin(); it != map.end(); ++it )
+ for( TQMap<TQ_UINT32, TQString>::ConstIterator it = map.begin(); it != map.end(); ++it )
addIncidence( type.latin1(), it.data(), folder, it.key() );
}
@@ -843,11 +843,11 @@ bool ResourceScalix::subresourceActive( const TQString& subresource ) const
// before it opens the resource :-( Make sure we are open
const_cast<ResourceScalix*>( this )->doOpen();
- if ( mEventSubResources.contains( subresource ) )
+ if ( mEventSubResources.tqcontains( subresource ) )
return mEventSubResources[ subresource ].active();
- if ( mTodoSubResources.contains( subresource ) )
+ if ( mTodoSubResources.tqcontains( subresource ) )
return mTodoSubResources[ subresource ].active();
- if ( mJournalSubResources.contains( subresource ) )
+ if ( mJournalSubResources.tqcontains( subresource ) )
return mJournalSubResources[ subresource ].active();
// Safe default bet:
@@ -860,11 +860,11 @@ void ResourceScalix::setSubresourceActive( const TQString &subresource, bool v )
{
ResourceMap *map = 0;
- if ( mEventSubResources.contains( subresource ) )
+ if ( mEventSubResources.tqcontains( subresource ) )
map = &mEventSubResources;
- if ( mTodoSubResources.contains( subresource ) )
+ if ( mTodoSubResources.tqcontains( subresource ) )
map = &mTodoSubResources;
- if ( mJournalSubResources.contains( subresource ) )
+ if ( mJournalSubResources.tqcontains( subresource ) )
map = &mJournalSubResources;
if ( map && ( ( *map )[ subresource ].active() != v ) ) {
@@ -689,11 +689,11 @@ void ResourceScalix::fromKMailDelIncidence( const TQString& type,
// It's good to know if was deleted, but we are waiting on a new one to
- // replace it, so let's just sit tight.
+ // tqreplace it, so let's just sit tight.
} else {
// We didn't trigger this, so KMail did, remove the reference to the uid